==> ssp-center-api-0.8.29-20201022.105927-15-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/accountAmountVerify/WebAccountAmountMonthRecordDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.accountAmountVerify;

public class WebAccountAmountMonthRecordDto extends AccountAmountVerifyLogDto {

    private static final long serialVersionUID = 1468732344070278791L;

    private Long hzBeginningAmount;

    private Long hegsBeginningAmount;

    private Long hcdjBeginningAmount;

    private Long hzFinalperiodAmount;

    private Long hegsFinalperiodAmount;

    private Long hcdjFinalperiodAmount;

    private Long hzSettlementAmount;

    private Long hegsSettlementAmount;

    private Long hcdjSettlementAmount;

    private Long hzCashAmount;

    private Long hegsCashAmount;

    private Long hcdjCashAmount;

    /**0-正常确认数据  1-调账数据**/
    private Integer recordType;

    public Long getHzBeginningAmount() {
        return hzBeginningAmount;
    }

    public void setHzBeginningAmount(Long hzBeginningAmount) {
        this.hzBeginningAmount = hzBeginningAmount;
    }

    public Long getHegsBeginningAmount() {
        return hegsBeginningAmount;
    }

    public void setHegsBeginningAmount(Long hegsBeginningAmount) {
        this.hegsBeginningAmount = hegsBeginningAmount;
    }

    public Long getHzFinalperiodAmount() {
        return hzFinalperiodAmount;
    }

    public void setHzFinalperiodAmount(Long hzFinalperiodAmount) {
        this.hzFinalperiodAmount = hzFinalperiodAmount;
    }

    public Long getHegsFinalperiodAmount() {
        return hegsFinalperiodAmount;
    }

    public void setHegsFinalperiodAmount(Long hegsFinalperiodAmount) {
        this.hegsFinalperiodAmount = hegsFinalperiodAmount;
    }

    public Long getHzSettlementAmount() {
        return hzSettlementAmount;
    }

    public void setHzSettlementAmount(Long hzSettlementAmount) {
        this.hzSettlementAmount = hzSettlementAmount;
    }

    public Long getHegsSettlementAmount() {
        return hegsSettlementAmount;
    }

    public void setHegsSettlementAmount(Long hegsSettlementAmount) {
        this.hegsSettlementAmount = hegsSettlementAmount;
    }

    public Long getHzCashAmount() {
        return hzCashAmount;
    }

    public void setHzCashAmount(Long hzCashAmount) {
        this.hzCashAmount = hzCashAmount;
    }

    public Long getHegsCashAmount() {
        return hegsCashAmount;
    }

    public void setHegsCashAmount(Long hegsCashAmount) {
        this.hegsCashAmount = hegsCashAmount;
    }

    public Long getHcdjFinalperiodAmount() {
        return hcdjFinalperiodAmount;
    }

    public void setHcdjFinalperiodAmount(Long hcdjFinalperiodAmount) {
        this.hcdjFinalperiodAmount = hcdjFinalperiodAmount;
    }

    public Long getHcdjSettlementAmount() {
        return hcdjSettlementAmount;
    }

    public void setHcdjSettlementAmount(Long hcdjSettlementAmount) {
        this.hcdjSettlementAmount = hcdjSettlementAmount;
    }

    public Long getHcdjCashAmount() {
        return hcdjCashAmount;
    }

    public void setHcdjCashAmount(Long hcdjCashAmount) {
        this.hcdjCashAmount = hcdjCashAmount;
    }

    public Long getHcdjBeginningAmount() {
        return hcdjBeginningAmount;
    }

    public void setHcdjBeginningAmount(Long hcdjBeginningAmount) {
        this.hcdjBeginningAmount = hcdjBeginningAmount;
    }

    public Integer getRecordType() {
        return recordType;
    }

    public void setRecordType(Integer recordType) {
        this.recordType = recordType;
    }
}

==> ssp-center-api-1.1.93-20231218.100336-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/accountAmountVerify/WebAccountAmountMonthRecordDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.accountAmountVerify;

public class WebAccountAmountMonthRecordDto extends AccountAmountVerifyLogDto {

    private static final long serialVersionUID = 1468732344070278791L;

    private Long hzBeginningAmount;

    private Long hegsBeginningAmount;

    private Long hcdjBeginningAmount;

    private Long duituiBeginningAmount;

    private Long hzFinalperiodAmount;

    private Long hegsFinalperiodAmount;

    private Long hcdjFinalperiodAmount;

    private Long duituiFinalperiodAmount;

    private Long hzSettlementAmount;

    private Long hegsSettlementAmount;

    private Long hcdjSettlementAmount;

    private Long duituiSettlementAmount;

    private Long hzCashAmount;

    private Long hegsCashAmount;

    private Long hcdjCashAmount;

    private Long duituiCashAmount;

    /**0-正常确认数据  1-调账数据**/
    private Integer recordType;

    public Long getHzBeginningAmount() {
        return hzBeginningAmount;
    }

    public void setHzBeginningAmount(Long hzBeginningAmount) {
        this.hzBeginningAmount = hzBeginningAmount;
    }

    public Long getHegsBeginningAmount() {
        return hegsBeginningAmount;
    }

    public void setHegsBeginningAmount(Long hegsBeginningAmount) {
        this.hegsBeginningAmount = hegsBeginningAmount;
    }

    public Long getHzFinalperiodAmount() {
        return hzFinalperiodAmount;
    }

    public void setHzFinalperiodAmount(Long hzFinalperiodAmount) {
        this.hzFinalperiodAmount = hzFinalperiodAmount;
    }

    public Long getHegsFinalperiodAmount() {
        return hegsFinalperiodAmount;
    }

    public void setHegsFinalperiodAmount(Long hegsFinalperiodAmount) {
        this.hegsFinalperiodAmount = hegsFinalperiodAmount;
    }

    public Long getHzSettlementAmount() {
        return hzSettlementAmount;
    }

    public void setHzSettlementAmount(Long hzSettlementAmount) {
        this.hzSettlementAmount = hzSettlementAmount;
    }

    public Long getHegsSettlementAmount() {
        return hegsSettlementAmount;
    }

    public void setHegsSettlementAmount(Long hegsSettlementAmount) {
        this.hegsSettlementAmount = hegsSettlementAmount;
    }

    public Long getHzCashAmount() {
        return hzCashAmount;
    }

    public void setHzCashAmount(Long hzCashAmount) {
        this.hzCashAmount = hzCashAmount;
    }

    public Long getHegsCashAmount() {
        return hegsCashAmount;
    }

    public void setHegsCashAmount(Long hegsCashAmount) {
        this.hegsCashAmount = hegsCashAmount;
    }

    public Long getHcdjFinalperiodAmount() {
        return hcdjFinalperiodAmount;
    }

    public void setHcdjFinalperiodAmount(Long hcdjFinalperiodAmount) {
        this.hcdjFinalperiodAmount = hcdjFinalperiodAmount;
    }

    public Long getHcdjSettlementAmount() {
        return hcdjSettlementAmount;
    }

    public void setHcdjSettlementAmount(Long hcdjSettlementAmount) {
        this.hcdjSettlementAmount = hcdjSettlementAmount;
    }

    public Long getHcdjCashAmount() {
        return hcdjCashAmount;
    }

    public void setHcdjCashAmount(Long hcdjCashAmount) {
        this.hcdjCashAmount = hcdjCashAmount;
    }

    public Long getHcdjBeginningAmount() {
        return hcdjBeginningAmount;
    }

    public void setHcdjBeginningAmount(Long hcdjBeginningAmount) {
        this.hcdjBeginningAmount = hcdjBeginningAmount;
    }

    public Long getDuituiBeginningAmount() {
        return duituiBeginningAmount;
    }

    public void setDuituiBeginningAmount(Long duituiBeginningAmount) {
        this.duituiBeginningAmount = duituiBeginningAmount;
    }

    public Long getDuituiFinalperiodAmount() {
        return duituiFinalperiodAmount;
    }

    public void setDuituiFinalperiodAmount(Long duituiFinalperiodAmount) {
        this.duituiFinalperiodAmount = duituiFinalperiodAmount;
    }

    public Long getDuituiSettlementAmount() {
        return duituiSettlementAmount;
    }

    public void setDuituiSettlementAmount(Long duituiSettlementAmount) {
        this.duituiSettlementAmount = duituiSettlementAmount;
    }

    public Long getDuituiCashAmount() {
        return duituiCashAmount;
    }

    public void setDuituiCashAmount(Long duituiCashAmount) {
        this.duituiCashAmount = duituiCashAmount;
    }

    public Integer getRecordType() {
        return recordType;
    }

    public void setRecordType(Integer recordType) {
        this.recordType = recordType;
    }
}
